@@ -4,8 +4,9 @@
 # can be used by non-unix systems that do not have built-in support
 # for shells.
 #
-# SCCS: @(#) console.tcl 1.45 97/09/17 16:52:40
+# RCS: @(#) $Id: console.tcl,v 1.6 1999/08/10 15:27:49 hobbs Exp $
 #
+# Copyright (c) 1998-1999 Scriptics Corp.
 # Copyright (c) 1995-1997 Sun Microsystems, Inc.
 #
 # See the file "license.terms" for information on usage and redistribution
@@ -23,14 +24,14 @@
 proc tkConsoleInit {} {
     global tcl_platform
 
-    if {! [consoleinterp eval {set tcl_interactive}]} {
+    if {![consoleinterp eval {set tcl_interactive}]} {
 	wm withdraw .
     }
 
-    if {"$tcl_platform(platform)" == "macintosh"} {
-	set mod "Cmd"
-    } else {
+    if {[string compare $tcl_platform(platform) "macintosh"]} {
 	set mod "Ctrl"
+    } else {
+      set mod "Cmd"
     }
 
     menu .menubar
@@ -42,10 +43,10 @@ proc tkConsoleInit {} {
 	-command tkConsoleSource
     .menubar.file add command -label "Hide Console" -underline 0 \
 	-command {wm withdraw .}
-    if {"$tcl_platform(platform)" == "macintosh"} {
-	.menubar.file add command -label "Quit" -command exit -accel Cmd-Q
-    } else {
+    if {[string compare $tcl_platform(platform) "macintosh"]} {
 	.menubar.file add command -label "Exit" -underline 1 -command exit
+    } else {
+      .menubar.file add command -label "Quit" -command exit -accel Cmd-Q
     }
 
     menu .menubar.edit -tearoff 0
@@ -56,7 +57,10 @@ proc tkConsoleInit {} {
     .menubar.edit add command -label "Paste" -underline 1 \
 	-command { event generate .console <<Paste>> } -accel "$mod+V"
 
-    if {"$tcl_platform(platform)" == "windows"} {
+    if {[string compare $tcl_platform(platform) "windows"]} {
+      .menubar.edit add command -label "Clear" -underline 2 \
+          -command { event generate .console <<Clear>> }
+    } else {
 	.menubar.edit add command -label "Delete" -underline 0 \
 	    -command { event generate .console <<Clear>> } -accel "Del"
 
@@ -64,18 +68,15 @@ proc tkConsoleInit {} {
 	menu .menubar.help -tearoff 0
 	.menubar.help add command -label "About..." -underline 0 \
 	    -command tkConsoleAbout
-    } else {
-	.menubar.edit add command -label "Clear" -underline 2 \
-	    -command { event generate .console <<Clear>> }
     }
 
-    . conf -menu .menubar
+    . configure -menu .menubar
 
     text .console  -yscrollcommand ".sb set" -setgrid true 
     scrollbar .sb -command ".console yview"
     pack .sb -side right -fill both
     pack .console -fill both -expand 1 -side left
-    if {$tcl_platform(platform) == "macintosh"} {
+    if {![string compare $tcl_platform(platform) "macintosh"]} {
         .console configure -font {Monaco 9 normal} -highlightthickness 0
     }
 
@@ -106,9 +107,9 @@ proc tkConsoleSource {} {
     set filename [tk_getOpenFile -defaultextension .tcl -parent . \
 		      -title "Select a file to source" \
 		      -filetypes {{"Tcl Scripts" .tcl} {"All Files" *}}]
-    if {"$filename" != ""} {
+    if {[string compare $filename ""]} {
     	set cmd [list source $filename]
-	if [catch {consoleinterp eval $cmd} result] {
+	if {[catch {consoleinterp eval $cmd} result]} {
 	    tkConsoleOutput stderr "$result\n"
 	}
     }
@@ -125,23 +126,23 @@ proc tkConsoleSource {} {
 proc tkConsoleInvoke {args} {
     set ranges [.console tag ranges input]
     set cmd ""
-    if {$ranges != ""} {
+    if {[llength $ranges]} {
 	set pos 0
-	while {[lindex $ranges $pos] != ""} {
+      while {[string compare [lindex $ranges $pos] ""]} {
 	    set start [lindex $ranges $pos]
 	    set end [lindex $ranges [incr pos]]
 	    append cmd [.console get $start $end]
 	    incr pos
 	}
     }
-    if {$cmd == ""} {
+    if {![string compare $cmd ""]} {
 	tkConsolePrompt
-    } elseif [info complete $cmd] {
+    } elseif {[info complete $cmd]} {
 	.console mark set output end
 	.console tag delete input
 	set result [consoleinterp record $cmd]
-	if {$result != ""} {
-	    .console insert insert "$result\n"
+      if {[string compare $result ""]} {
+	    puts $result
 	}
 	tkConsoleHistory reset
 	tkConsolePrompt
@@ -168,7 +169,7 @@ proc tkConsoleHistory {cmd} {
     	prev {
 	    incr histNum -1
 	    if {$histNum == 0} {
-		set cmd {history event [expr [history nextid] -1]}
+		set cmd {history event [expr {[history nextid] -1}]}
 	    } else {
 		set cmd "history event $histNum"
 	    }
@@ -182,14 +183,14 @@ proc tkConsoleHistory {cmd} {
     	next {
 	    incr histNum
 	    if {$histNum == 0} {
-		set cmd {history event [expr [history nextid] -1]}
+		set cmd {history event [expr {[history nextid] -1}]}
 	    } elseif {$histNum > 0} {
 		set cmd ""
 		set histNum 1
 	    } else {
 		set cmd "history event $histNum"
 	    }
-	    if {$cmd != ""} {
+          if {[string compare $cmd ""]} {
 		catch {consoleinterp eval $cmd} cmd
 	    }
 	    .console delete promptEnd end
@@ -210,10 +211,10 @@ proc tkConsoleHistory {cmd} {
 # partial -	Flag to specify which prompt to print.
 
 proc tkConsolePrompt {{partial normal}} {
-    if {$partial == "normal"} {
+    if {![string compare $partial "normal"]} {
 	set temp [.console index "end - 1 char"]
 	.console mark set output end
-    	if [consoleinterp eval "info exists tcl_prompt1"] {
+    	if {[consoleinterp eval "info exists tcl_prompt1"]} {
     	    consoleinterp eval "eval \[set tcl_prompt1\]"
     	} else {
     	    puts -nonewline "% "
@@ -221,7 +222,7 @@ proc tkConsolePrompt {{partial normal}} {
     } else {
 	set temp [.console index output]
 	.console mark set output end
-    	if [consoleinterp eval "info exists tcl_prompt2"] {
+    	if {[consoleinterp eval "info exists tcl_prompt2"]} {
     	    consoleinterp eval "eval \[set tcl_prompt2\]"
     	} else {
 	    puts -nonewline "> "
@@ -268,26 +269,26 @@ proc tkConsoleBind {win} {
 	break
     }
     bind $win <Delete> {
-	if {[%W tag nextrange sel 1.0 end] != ""} {
+      if {[string compare [%W tag nextrange sel 1.0 end] ""]} {
 	    %W tag remove sel sel.first promptEnd
 	} else {
-	    if [%W compare insert < promptEnd] {
+	    if {[%W compare insert < promptEnd]} {
 		break
 	    }
 	}
     }
     bind $win <BackSpace> {
-	if {[%W tag nextrange sel 1.0 end] != ""} {
+      if {[string compare [%W tag nextrange sel 1.0 end] ""]} {
 	    %W tag remove sel sel.first promptEnd
 	} else {
-	    if [%W compare insert <= promptEnd] {
+	    if {[%W compare insert <= promptEnd]} {
 		break
 	    }
 	}
     }
     foreach left {Control-a Home} {
 	bind $win <$left> {
-	    if [%W compare insert < promptEnd] {
+	    if {[%W compare insert < promptEnd]} {
 		tkTextSetCursor %W {insert linestart}
 	    } else {
 		tkTextSetCursor %W promptEnd
@@ -302,32 +303,32 @@ proc tkConsoleBind {win} {
 	}
     }
     bind $win <Control-d> {
-	if [%W compare insert < promptEnd] {
+	if {[%W compare insert < promptEnd]} {
 	    break
 	}
     }
     bind $win <Control-k> {
-	if [%W compare insert < promptEnd] {
+	if {[%W compare insert < promptEnd]} {
 	    %W mark set insert promptEnd
 	}
     }
     bind $win <Control-t> {
-	if [%W compare insert < promptEnd] {
+	if {[%W compare insert < promptEnd]} {
 	    break
 	}
     }
     bind $win <Meta-d> {
-	if [%W compare insert < promptEnd] {
+	if {[%W compare insert < promptEnd]} {
 	    break
 	}
     }
     bind $win <Meta-BackSpace> {
-	if [%W compare insert <= promptEnd] {
+	if {[%W compare insert <= promptEnd]} {
 	    break
 	}
     }
     bind $win <Control-h> {
-	if [%W compare insert <= promptEnd] {
+	if {[%W compare insert <= promptEnd]} {
 	    break
 	}
     }
@@ -353,7 +354,7 @@ proc tkConsoleBind {win} {
     }
     foreach left {Control-b Left} {
 	bind $win <$left> {
-	    if [%W compare insert == promptEnd] {
+	    if {[%W compare insert == promptEnd]} {
 		break
 	    }
 	    tkTextSetCursor %W insert-1c
@@ -368,7 +369,7 @@ proc tkConsoleBind {win} {
     }
     bind $win <F9> {
 	eval destroy [winfo child .]
-	if {$tcl_platform(platform) == "macintosh"} {
+      if {![string compare $tcl_platform(platform) "macintosh"]} {
 	    source -rsrc Console
 	} else {
 	    source [file join $tk_library console.tcl]
@@ -416,7 +417,7 @@ proc tkConsoleBind {win} {
 # s -		The string to insert (usually just a single character)
 
 proc tkConsoleInsert {w s} {
-    if {$s == ""} {
+    if {![string compare $s ""]} {
 	return
     }
     catch {
@@ -470,7 +471,7 @@ proc tkConsoleExit {} {
 proc tkConsoleAbout {} {
     global tk_patchLevel
     tk_messageBox -type ok -message "Tcl for Windows
-Copyright \251 1996 Sun Microsystems, Inc.
+Copyright \251 1999 Scriptics Corporation
 
 Tcl [info patchlevel]
 Tk $tk_patchLevel"
