@@ -3,10 +3,10 @@
 # This file defines the procedure tk_dialog, which creates a dialog
 # box containing a bitmap, a message, and one or more buttons.
 #
-# SCCS: @(#) dialog.tcl 1.26 96/05/07 09:30:31
+# RCS: @(#) $Id: dialog.tcl,v 1.4.6.1 1999/09/24 22:17:58 hobbs Exp $
 #
 # Copyright (c) 1992-1993 The Regents of the University of California.
-# Copyright (c) 1994-1996 Sun Microsystems, Inc.
+# Copyright (c) 1994-1997 Sun Microsystems, Inc.
 #
 # See the file "license.terms" for information on usage and redistribution
 # of this file, and for a DISCLAIMER OF ALL WARRANTIES.
@@ -30,7 +30,7 @@
 #		bottom of the dialog box.
 
 proc tk_dialog {w title text bitmap default args} {
-    global tkPriv
+    global tkPriv tcl_platform
 
     # 1. Create the top-level window and divide it into top
     # and bottom parts.
@@ -47,22 +47,36 @@ proc tk_dialog {w title text bitmap default args} {
     # even though its grab keeps the rest of the application from being used.
 
     wm transient $w [winfo toplevel [winfo parent $w]]
-    frame $w.bot -relief raised -bd 1
+    if {![string compare $tcl_platform(platform) "macintosh"]} {
+	unsupported1 style $w dBoxProc
+    }
+
+    frame $w.bot
+    frame $w.top
+    if {![string compare $tcl_platform(platform) "unix"]} {
+	$w.bot configure -relief raised -bd 1
+	$w.top configure -relief raised -bd 1
+    }
     pack $w.bot -side bottom -fill both
-    frame $w.top -relief raised -bd 1
     pack $w.top -side top -fill both -expand 1
 
     # 2. Fill the top part with bitmap and message (use the option
-    # database for -wraplength so that it can be overridden by
-    # the caller).
+    # database for -wraplength and -font so that they can be
+    # overridden by the caller).
 
     option add *Dialog.msg.wrapLength 3i widgetDefault
-    label $w.msg -justify left -text $text
-    catch {$w.msg configure -font \
-		-Adobe-Times-Medium-R-Normal--*-180-*-*-*-*-*-*
+    if {![string compare $tcl_platform(platform) "macintosh"]} {
+	option add *Dialog.msg.font system widgetDefault
+    } else {
+	option add *Dialog.msg.font {Times 12} widgetDefault
     }
+
+    label $w.msg -justify left -text $text
     pack $w.msg -in $w.top -side right -expand 1 -fill both -padx 3m -pady 3m
-    if {$bitmap != ""} {
+    if {[string compare $bitmap ""]} {
+      if {![string compare $tcl_platform(platform) "macintosh"] && ![string compare $bitmap "error"]} {
+	    set bitmap "stop"
+	}
 	label $w.bitmap -bitmap $bitmap
 	pack $w.bitmap -in $w.top -side left -padx 3m -pady 3m
     }
@@ -73,13 +87,18 @@ proc tk_dialog {w title text bitmap default args} {
     foreach but $args {
 	button $w.button$i -text $but -command "set tkPriv(button) $i"
 	if {$i == $default} {
-	    frame $w.default -relief sunken -bd 1
-	    raise $w.button$i $w.default
-	    pack $w.default -in $w.bot -side left -expand 1 -padx 3m -pady 2m
-	    pack $w.button$i -in $w.default -padx 2m -pady 2m
+	    $w.button$i configure -default active
 	} else {
-	    pack $w.button$i -in $w.bot -side left -expand 1 \
-		    -padx 3m -pady 2m
+	    $w.button$i configure -default normal
+	}
+	grid $w.button$i -in $w.bot -column $i -row 0 -sticky ew -padx 10
+	grid columnconfigure $w.bot $i
+	# We boost the size of some Mac buttons for l&f
+      if {![string compare $tcl_platform(platform) "macintosh"]} {
+	    set tmp [string tolower $but]
+          if {![string compare $tmp "ok"] || ![string compare $tmp "cancel"]} {
+		grid columnconfigure $w.bot $i -minsize [expr 59 + 20]
+	    }
 	}
 	incr i
     }
@@ -89,7 +108,7 @@ proc tk_dialog {w title text bitmap default args} {
 
     if {$default >= 0} {
 	bind $w <Return> "
-	    $w.button$default configure -state active -relief sunken
+          [list $w.button$default] configure -state active -relief sunken
 	    update idletasks
 	    after 100
 	    set tkPriv(button) $default
@@ -108,10 +127,10 @@ proc tk_dialog {w title text bitmap default args} {
 
     wm withdraw $w
     update idletasks
-    set x [expr [winfo screenwidth $w]/2 - [winfo reqwidth $w]/2 \
-	    - [winfo vrootx [winfo parent $w]]]
-    set y [expr [winfo screenheight $w]/2 - [winfo reqheight $w]/2 \
-	    - [winfo vrooty [winfo parent $w]]]
+    set x [expr {[winfo screenwidth $w]/2 - [winfo reqwidth $w]/2 \
+	    - [winfo vrootx [winfo parent $w]]}]
+    set y [expr {[winfo screenheight $w]/2 - [winfo reqheight $w]/2 \
+	    - [winfo vrooty [winfo parent $w]]}]
     wm geom $w +$x+$y
     wm deiconify $w
 
@@ -119,7 +138,7 @@ proc tk_dialog {w title text bitmap default args} {
 
     set oldFocus [focus]
     set oldGrab [grab current $w]
-    if {$oldGrab != ""} {
+    if {[string compare $oldGrab ""]} {
 	set grabStatus [grab status $oldGrab]
     }
     grab $w
@@ -145,11 +164,11 @@ proc tk_dialog {w title text bitmap default args} {
 	bind $w <Destroy> {}
 	destroy $w
     }
-    if {$oldGrab != ""} {
-	if {$grabStatus == "global"} {
-	    grab -global $oldGrab
-	} else {
+    if {[string compare $oldGrab ""]} {
+      if {[string compare $grabStatus "global"]} {
 	    grab $oldGrab
+      } else {
+          grab -global $oldGrab
 	}
     }
     return $tkPriv(button)
