@@ -9,7 +9,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: winMain.c,v 1.6 1999/04/16 01:51:55 stanton Exp $
+ * RCS: @(#) $Id: winMain.c,v 1.7.6.1 1999/11/03 00:43:09 hobbs Exp $
  */
 
 #include <tk.h>
@@ -95,7 +95,7 @@ WinMain(hInstance, hPrevInstance, lpszCmdLine, nCmdShow)
 
     /*
      * Create the console channels and install them as the standard
-     * channels.  All I/O will be discarded until TkConsoleInit is
+     * channels.  All I/O will be discarded until Tk_CreateConsoleWindow is
      * called to attach the console to a text widget.
      */
 
@@ -143,7 +143,7 @@ Tcl_AppInit(interp)
      */
 
     if (consoleRequired) {
-	if (TkConsoleInit(interp) == TCL_ERROR) {
+	if (Tk_CreateConsoleWindow(interp) == TCL_ERROR) {
 	    goto error;
 	}
     }
@@ -171,7 +171,11 @@ Tcl_AppInit(interp)
     return TCL_OK;
 
 error:
-    WishPanic(Tcl_GetStringResult(interp));
+    MessageBeep(MB_ICONEXCLAMATION);
+    MessageBox(NULL, Tcl_GetStringResult(interp), "Error in Wish",
+	    MB_ICONSTOP | MB_OK | MB_TASKMODAL | MB_SETFOREGROUND);
+    ExitProcess(1);
+    /* we won't reach this, but we need the return */
     return TCL_ERROR;
 }
 
@@ -209,6 +213,7 @@ WishPanic TCL_VARARGS_DEF(char *,arg1)
 #endif
     ExitProcess(1);
 }
+
 /*
  *-------------------------------------------------------------------------
  *
@@ -325,7 +330,6 @@ setargv(argcPtr, argvPtr)
     *argcPtr = argc;
     *argvPtr = argv;
 }
-
 
 /*
  *----------------------------------------------------------------------
@@ -366,7 +370,7 @@ int main(int argc, char **argv)
 
     /*
      * Create the console channels and install them as the standard
-     * channels.  All I/O will be discarded until TkConsoleInit is
+     * channels.  All I/O will be discarded until Tk_CreateConsoleWindow is
      * called to attach the console to a text widget.
      */
 
